@@ -18,6 +18,7 @@
 #
 ##########################################################################
 import urllib2
+from lib.common import USER_AGENT
 from lxml import etree
 from lxml import objectify
 from StringIO import StringIO
@@ -30,10 +31,7 @@ class AsxPlaylistDecoder:
 
     def isStreamValid(self, contentType, firstBytes):
 
-        if('audio/x-ms-wax' in contentType or 'video/x-ms-wvx' in contentType):
-            print "Stream is readable by ASX Playlist Decoder"
-            return True
-        elif(contentType == 'video/x-ms-asf' and firstBytes.strip().lower().startswith('<asx')):
+        if(('audio/x-ms-wax' in contentType or 'video/x-ms-wvx' in contentType or 'video/x-ms-asf' in contentType or 'video/x-ms-wmv' in contentType) and firstBytes.strip().lower().startswith('<asx')):
             print "Stream is readable by ASX Playlist Decoder"
             return True
         else:
@@ -45,6 +43,7 @@ class AsxPlaylistDecoder:
         print "Downloading playlist..."
 
         req = urllib2.Request(url)
+        req.add_header('User-Agent', USER_AGENT)
         f = urllib2.urlopen(req)
         str = f.read()
         f.close()
