@@ -23,6 +23,7 @@ import pygst
 pygst.require("0.10")
 import gst
 from StreamDecoder import StreamDecoder
+from lib.common import USER_AGENT
 
 class AudioPlayerGStreamer:
 
@@ -33,29 +34,36 @@ class AudioPlayerGStreamer:
         self.playlist = []
 
         # init player
-        self.player = gst.element_factory_make("playbin2", "player")
+        self.souphttpsrc = gst.element_factory_make("souphttpsrc", "source")
+        self.souphttpsrc.set_property("user-agent", USER_AGENT)
+		
+        self.player = gst.element_factory_make("playbin2", "player")		
         fakesink = gst.element_factory_make("fakesink", "fakesink")
         self.player.set_property("video-sink", fakesink)
         bus = self.player.get_bus()
         bus.add_signal_watch()
         bus.connect("message", self.on_message)
 
-
     def start(self, uri):
 
         urlInfo = self.decoder.getMediaStreamInfo(uri)
 
         if(urlInfo is not None and urlInfo.isPlaylist()):
             self.playlist = self.decoder.getPlaylist(urlInfo)
+            if(len(self.playlist) == 0):
+                print "Received empty playlist!"
+                self.mediator.stop()
+                self.mediator.notifyError(_("Connection Error"), _("Received empty stream from station"))
             print self.playlist
             self.playNextStream()
 
         elif(urlInfo is not None and urlInfo.isPlaylist() == False):
-            self.playlist = [uri]
+            self.playlist = [urlInfo.getUrl()]
             self.playNextStream()
 
         else:            
             self.mediator.stop()
+            self.mediator.notifyError(_("Connection Error"), _("Couldn't read stream from station"))
 
 
     def playNextStream(self):
@@ -66,7 +74,7 @@ class AudioPlayerGStreamer:
             urlInfo = self.decoder.getMediaStreamInfo(stream)
             if(urlInfo is not None and urlInfo.isPlaylist() == False):
                 self.player.set_property("uri", stream)
-                self.player.set_state(gst.STATE_PLAYING)
+                self.player.set_state(gst.STATE_PAUSED) # buffer before starting playback
             elif(urlInfo is not None and urlInfo.isPlaylist()):
                 self.playlist = self.decoder.getPlaylist(urlInfo) + self.playlist
                 self.playNextStream()
@@ -94,7 +102,11 @@ class AudioPlayerGStreamer:
             self.log.log("Received MESSAGE_EOS")
             self.player.set_state(gst.STATE_NULL)
             self.playNextStream()
-
+        elif t == gst.MESSAGE_BUFFERING:
+            if message.structure['buffer-percent'] == 0:
+                self.player.set_state(gst.STATE_PAUSED)
+            else:
+                self.player.set_state(gst.STATE_PLAYING)
         elif t == gst.MESSAGE_ERROR:
             self.log.log("Received MESSAGE_ERROR")
             self.player.set_state(gst.STATE_NULL)
