@@ -33,6 +33,7 @@ except:
     sys.exit(1)
 
 from XmlDataProvider import XmlDataProvider
+from lib.common import APP_ICON_ON
 from lib import utils
 from lib import i18n
 import uuid
@@ -73,6 +74,12 @@ class BookmarkConfiguration(object):
         self.currentGroupLabel = self.wTree.get_object("label7")
         self.newGroupCombo = self.wTree.get_object("newGroup")
 
+        # set icon
+        self.window.set_icon_from_file(APP_ICON_ON)
+        self.config.set_icon_from_file(APP_ICON_ON)
+        self.moveGroupDialog.set_icon_from_file(APP_ICON_ON)
+        self.configGroup.set_icon_from_file(APP_ICON_ON)
+
         # populate list of radios
         self.load_data()
         
@@ -129,6 +136,10 @@ class BookmarkConfiguration(object):
             iter = treestore.append(parent, [group.get('name'), group.get('name'), self.GROUP_TYPE])
         
         for item in group:
+            
+            if item.get('name') == None:                
+                continue
+            
             if (item.tag == 'bookmark'):
                 if(item.get('name').startswith('[separator')):
                     treestore.append(iter, ['-- Separator --', item.get('name'), self.SEPARATOR_TYPE])
@@ -148,11 +159,8 @@ class BookmarkConfiguration(object):
 
             if (selectedRadioName.startswith("[separator-")):
                 self.wTree.get_object("editBookmarkButton").set_sensitive(False)
-                self.wTree.get_object("moveToGroup").set_sensitive(False)
             else:
                 self.wTree.get_object("editBookmarkButton").set_sensitive(True)
-                self.wTree.get_object("moveToGroup").set_sensitive(True)
-
 
     def on_add_separator_clicked(self, widget):
         # hack: generate a unique name
@@ -178,6 +186,21 @@ class BookmarkConfiguration(object):
             print "group found: " + group
             
         self.radioGroup.set_model(liststore)
+        
+        # default to root
+        self.radioGroup.set_active(0)
+        
+        # get current selected group and set it as default
+        selection = self.list.get_selection()
+        (model, iter) = selection.get_selected()
+
+        if type(iter).__name__=='TreeIter':
+            selectedName = model.get_value(iter,1)
+            selectedType = model.get_value(iter, 2)
+            
+            if (selectedType == self.GROUP_TYPE):
+                groupIndex = self.dataProvider.listGroupNames().index(selectedName)
+                self.radioGroup.set_active(groupIndex)
 
         # show dialog
         result = self.config.run()
@@ -291,9 +314,9 @@ class BookmarkConfiguration(object):
 
                 confirmation.hide()
             else:
-                 self.dataProvider.removeRadio(separatorFlag)
-                 # remove from gui
-                 model.remove(iter)
+                self.dataProvider.removeRadio(separatorFlag)
+                # remove from gui
+                model.remove(iter)
 
 
     def on_moveup_bookmark_clicked(self, widget):
@@ -371,7 +394,21 @@ class BookmarkConfiguration(object):
             print "group found: " + group
             
         self.parentGroup.set_model(liststore)
-              
+            
+        # default to root
+        self.parentGroup.set_active(0)
+        
+        # get current selected group and set it as default
+        selection = self.list.get_selection()
+        (model, iter) = selection.get_selected()
+
+        if type(iter).__name__=='TreeIter':
+            selectedName = model.get_value(iter,1)
+            selectedType = model.get_value(iter, 2)
+            
+            if (selectedType == self.GROUP_TYPE):
+                groupIndex = self.dataProvider.listGroupNames().index(selectedName)
+                self.parentGroup.set_active(groupIndex)
 
         # show dialog
         result = self.configGroup.run()
@@ -411,14 +448,17 @@ class BookmarkConfiguration(object):
             
             self.newGroupCombo.set_model(liststore)
 
-            if (selectedType == self.RADIO_TYPE):
+            if (selectedType == self.RADIO_TYPE) or (selectedType == self.SEPARATOR_TYPE):
                 #get radio bookmark details
                 selectedRadio = self.dataProvider._radioExists(selectedName)
                 currentGroup = selectedRadio.getparent().get("name")
                 
                 # populate dialog with radio information
                 self.currentGroupLabel.set_text(currentGroup)
-                self.moveGroupDialog.set_title(_('Edit %s') % selectedName)
+                if not selectedName.startswith("[separator-"):
+                    self.moveGroupDialog.set_title(_('Edit %s') % selectedName)
+                else:
+                    self.moveGroupDialog.set_title(_('Edit Separator'))
                 self.newGroupCombo.grab_focus()
 
                 # show dialog
@@ -448,7 +488,8 @@ class BookmarkConfiguration(object):
                     index = self.newGroupCombo.get_active()
                     new_group = liststore[index][0]
                     
-                    self.dataProvider.updateElementGroup(selectedGroup, new_group)
+                    if new_group != selectedName:
+                        self.dataProvider.updateElementGroup(selectedGroup, new_group)
                     
                 self.moveGroupDialog.hide()
             self.load_data()
