@@ -18,6 +18,7 @@
 #
 ##########################################################################
 import urllib2
+from lib.common import USER_AGENT
 
 class PlsPlaylistDecoder:
 
@@ -40,6 +41,7 @@ class PlsPlaylistDecoder:
             print "Downloading playlist..."
             
             req = urllib2.Request(url)
+            req.add_header('User-Agent', USER_AGENT)
             f = urllib2.urlopen(req)
             str = f.read()
             f.close()
