@@ -18,6 +18,7 @@
 #
 ##########################################################################
 import urllib2
+from lib.common import USER_AGENT
 
 class RamPlaylistDecoder:
 
@@ -38,6 +39,7 @@ class RamPlaylistDecoder:
         print "Downloading playlist..."
 
         req = urllib2.Request(url)
+        req.add_header('User-Agent', USER_AGENT)
         f = urllib2.urlopen(req)
         str = f.read()
         f.close()
