@@ -30,10 +30,16 @@ class StateMediator(object):
         self.notification = notification
         self.isPlaying = False
         self.isNotified = False
-        self.currentRadio = ''
+        
+        radio = self.cfg_provider.getConfigValue("last_station")
+        self.currentRadio = '' if not radio else radio 
         self.currentMetaData = ''
         self.volume = float(self.cfg_provider.getConfigValue("volume_level"))
         self.bitrate = 0
+        
+        # validate station
+        if not self.provider.getRadioUrl(radio):
+            self.currentRadio = ''
 
     def setAudioPlayer(self, audioPlayer):
         self.audioPlayer = audioPlayer
@@ -51,11 +57,13 @@ class StateMediator(object):
         self.currentMetaData = ''
 
         url = self.provider.getRadioUrl(radio)
+        self.systray.setConnectingState(radio)        
         self.audioPlayer.start(url)
-        self.systray.setConnectingState(radio)
         self.currentRadio = radio
         self.isNotified = False
-
+               
+        self.cfg_provider.setConfigValue("last_station", radio)
+               
     def playUrl(self, url):
 
         if(self.isPlaying):
@@ -66,10 +74,14 @@ class StateMediator(object):
         self.currentRadio = C_("Unknown radio specified by URL", "Unknown radio")
         self.isNotified = False
 
+    def playLast(self):
+        if self.currentRadio:
+            self.play(self.currentRadio)
+
     def stop(self):
         self.audioPlayer.stop()
-        self.systray.setStoppedState()
         self.isPlaying = False
+        self.systray.setStoppedState()        
         self.isNotified = False
 
     def volume_up(self):
@@ -122,7 +134,10 @@ class StateMediator(object):
         return self.currentRadio
 
     def getCurrentMetaData(self):
-        return self.currentMetaData
+        if self.isPlaying:
+            return self.currentMetaData
+        else:
+            return "Not Playing"
 
     def updateVolume(self, volume):
         self.volume = volume
