@@ -18,6 +18,8 @@
 #
 ##########################################################################
 import urllib2
+from lib.common import USER_AGENT
+from lib.DummyMMSHandler import DummyMMSHandler
 from PlsPlaylistDecoder import PlsPlaylistDecoder
 from M3uPlaylistDecoder import M3uPlaylistDecoder
 from AsxPlaylistDecoder import AsxPlaylistDecoder
@@ -44,11 +46,11 @@ class StreamDecoder:
             self.url_timeout = cfg_provider.getConfigValue("url_timeout")
             if (self.url_timeout == None):
                 print "Couldn't find url_timeout configuration"
-                self.url_timeout = 2000
+                self.url_timeout = 100
                 cfg_provider.setConfigValue("url_timeout", str(self.url_timeout))
         except Exception, e:
             print "Couldn't find url_timeout configuration"
-            self.url_timeout = 2000
+            self.url_timeout = 100
             cfg_provider.setConfigValue("url_timeout", str(self.url_timeout))
 
         print "Using url timeout = " + str(self.url_timeout)
@@ -62,12 +64,23 @@ class StreamDecoder:
 
         print "Requesting stream... " + url
         req = urllib2.Request(url)
-        try:
-            f = urllib2.urlopen(req, timeout=float(self.url_timeout))
+        req.add_header('User-Agent', USER_AGENT)
 
+        try:
+            opener = urllib2.build_opener(DummyMMSHandler())
+            f = opener.open(req, timeout=float(self.url_timeout))
+
+        except urllib2.HTTPError, e:
+            print "HTTP Error: No radio stream found for %s" % url
+            return None
         except urllib2.URLError, e:
             print "No radio stream found for %s" % url
-            return None
+            if str(e.reason).startswith('MMS REDIRECT'):
+                newurl = e.reason.split("MMS REDIRECT:",1)[1]
+                print "Found mms redirect for: " + newurl
+                return UrlInfo(newurl, False, None)
+            else:
+                return None
         except Exception, e:
             print "No radio stream found. Error: %s" % str(e)
             return None
