@@ -59,7 +59,11 @@ class XmlDataProvider:
         
     def listGroupNames(self):
     
-    	return self.root.xpath("//group/@name")
+        return self.root.xpath("//group/@name")
+  
+    def listRadiosInGroup(self, group):
+
+        return self.root.xpath("//group[@name=$var]/bookmark/@name", var=group)
 
     def getRadioUrl(self, name):
 
@@ -79,7 +83,7 @@ class XmlDataProvider:
             if group == None or len(group) == 0:
                 print "Group is new. Saving with name " + new_group_name
                 new_group = etree.SubElement(parent_group[0], 'group')
-                new_group.set("name", new_group_name)
+                new_group.set("name", unicode(new_group_name))
                 self.saveToFile()                
                 return True        
             
@@ -102,8 +106,8 @@ class XmlDataProvider:
     
             if result is None:
                 radio = etree.SubElement(group[0], 'bookmark')
-                radio.set("name", name)
-                radio.set("url", url)
+                radio.set("name", unicode(name))
+                radio.set("url", unicode(url))
                 self.saveToFile()
                 return True
             
@@ -126,7 +130,7 @@ class XmlDataProvider:
             radioAdded = False
         else:
             if oldName == newName:
-                result.set("url", url)
+                result.set("url", unicode(url))
                 self.saveToFile()
                 radioAdded = True
             else:
@@ -136,7 +140,7 @@ class XmlDataProvider:
                     radioAdded = False
                 else:
                     result.set("name", unicode(newName))
-                    result.set("url", url)
+                    result.set("url", unicode(url))
                     self.saveToFile()
                     radioAdded = True
 
@@ -160,7 +164,7 @@ class XmlDataProvider:
                     print "A group with the name \"%s\" already exists." % newName
                     groupAdded = False
                 else:
-                    result.set("name", newNameStr)
+                    result.set("name", unicode(newNameStr))
                     self.saveToFile()
                     groupAdded = True
 
@@ -285,6 +289,9 @@ class XmlDataProvider:
                 
         for child in children:                    
             child_name  = child.get('name')
+                
+            if child_name == None:
+                continue
                        
             if  child.tag == 'group':                
                 new_user_data = group_func(child_name, user_data)
